pub enum ScalarKind {
Show 21 variants
Account,
Blob,
Bool,
Date,
Decimal,
Duration,
Enum,
Float32,
Float64,
Int,
Int128,
IntBig,
Principal,
Subaccount,
Text,
Timestamp,
Uint,
Uint128,
UintBig,
Ulid,
Unit,
}Expand description
ScalarKind
Canonical scalar kind used for shared capability metadata.
Variants
Account
Blob
Bool
Date
Decimal
Duration
Enum
Float32
Float64
Int
Int128
IntBig
Principal
Subaccount
Text
Timestamp
Uint
Uint128
UintBig
Ulid
Unit
Implementations
Sourceimpl ScalarKind
impl ScalarKind
Sourcepub const fn metadata(self) -> ScalarMetadata
pub const fn metadata(self) -> ScalarMetadata
Return the full metadata descriptor for one scalar kind.
Sourcepub const fn coercion_family(self) -> ScalarCoercionFamily
pub const fn coercion_family(self) -> ScalarCoercionFamily
Return coercion routing family for this scalar kind.
Sourcepub const fn is_numeric_value(self) -> bool
pub const fn is_numeric_value(self) -> bool
Return whether this scalar participates in numeric-valued classification.
Sourcepub const fn supports_numeric_coercion(self) -> bool
pub const fn supports_numeric_coercion(self) -> bool
Return whether this scalar supports numeric widening coercion.
Sourcepub const fn supports_arithmetic(self) -> bool
pub const fn supports_arithmetic(self) -> bool
Return whether this scalar supports arithmetic trait derivation.
Sourcepub const fn supports_equality(self) -> bool
pub const fn supports_equality(self) -> bool
Return whether this scalar supports equality predicates.
Sourcepub const fn supports_ordering(self) -> bool
pub const fn supports_ordering(self) -> bool
Return whether this scalar supports ordering predicates.
Sourcepub const fn is_keyable(self) -> bool
pub const fn is_keyable(self) -> bool
Return whether this scalar is keyable at query/schema level.
Sourcepub const fn is_storage_key_encodable(self) -> bool
pub const fn is_storage_key_encodable(self) -> bool
Return whether this scalar can be encoded as a storage key.