ScalarKind

Enum ScalarKind 

pub enum ScalarKind {
Show 21 variants Account, Blob, Bool, Date, Decimal, Duration, Enum, Float32, Float64, Int, Int128, IntBig, Principal, Subaccount, Text, Timestamp, Nat, Nat128, NatBig, Ulid, Unit,
}
ScalarKind

Canonical scalar kind used for shared capability metadata.

Variants



Account



Blob



Bool



Date



Decimal



Duration



Enum



Float32



Float64



Int



Int128



IntBig



Principal



Subaccount



Text



Timestamp



Nat



Nat128



NatBig



Ulid



Unit

Implementations

Source

impl ScalarKind

pub const fn metadata(self) -> ScalarMetadata

Return the full metadata descriptor for one scalar kind.

pub const fn coercion_family(self) -> ScalarCoercionFamily

Return coercion routing family for this scalar kind.

pub const fn is_numeric_value(self) -> bool

Return whether this scalar participates in numeric-valued classification.

pub const fn supports_numeric_coercion(self) -> bool

Return whether this scalar supports numeric widening coercion.

pub const fn supports_arithmetic(self) -> bool

Return whether this scalar supports arithmetic trait derivation.

pub const fn supports_equality(self) -> bool

Return whether this scalar supports equality predicates.

pub const fn supports_ordering(self) -> bool

Return whether this scalar supports ordering predicates.

pub const fn is_keyable(self) -> bool

Return whether this scalar is keyable at query/schema level.

pub const fn is_primary_key_component_encodable(self) -> bool

Return whether this scalar can be encoded as a storage key.